@@ -598,3 +598,21 @@ def gsuite(fid_or_url, width=1200, height=1000):
         print(f'X-Frame-Option = {xframeoptions}\nEmbedding in IFrame is not allowed for {url}.')
     else:
         return IFrame(url, width, height)
+
+
+    # This is a good idea, but it would only work in colab?
+def read_csv(url, sheet_name='Sheet1', *args, **kwargs):
+    '''Return a dataframe for the Google Sheet at url.
+    sheet_name : the name of the sheet to read.
+    args and kwargs are passed to pd.read_csv
+
+    The url should be viewable by anyone with the link.
+    """
+    
+
+    adapted from https://towardsdatascience.com/read-data-from-google-sheets-into-pandas-without-the-google-sheets-api-5c468536550'''
+    fid = fid_from_url(url)
+    url = (f'https://docs.google.com/spreadsheets/d/{sheet_id}'
+           f'/gviz/tq?tqx=out:csv&sheet={sheet_name}')
+
+    return pd.read_csv(url, *args, **kwargs)
